@@ -133,12 +133,12 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
 
         if (!isNonInteractivePlot && !plotInteractive) {
             warning(sQuote("plot"), " is ", sQuote("TRUE"),
-                    " but no non-interactive devices is available.",
+                    " but no non-interactive devices is available. ",
                     "Using pdf() to create a default one.");
             pdf(paper="a4r", width=12);
         } else if (dev.cur() == 1 && plotInteractive) {
             warning(sQuote("plot"), " is ", sQuote("TRUE"), 
-                    " but no interactive devices is available.",
+                    " but no interactive devices is available. ",
                     "Using dev.new() to create a default one.");
             dev.new();
         }
@@ -198,10 +198,6 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
         }
     }
 
-    if (length(warpingFunctions) == 1) {
-        return(warpingFunctions[[1]]);
-    } else {
-        return(warpingFunctions);
-    }
+    return(warpingFunctions);
 }
 
