@@ -36,9 +36,9 @@ setMethod(f=".isEmptyWarning",
                          x@metaData$file, ")", sep="");
         }
 
-        parentCall <- sys.call(sys.nframe()-1L);
-        warning(paste("In ", parentCall, " : ", msg, " is empty!", sep=""), 
-                call.=FALSE);
+        parentCall <- sys.call(-1);
+        warning(paste("In ", deparse(parentCall), " : ", msg, " is empty!",
+                      sep=""), call.=FALSE);
         return(TRUE);
     }
 
